function new_cost = estimate_remove_vars( this, vars )

% new_cost = estimate_remove_vars( this, vars )
%
% Estimates the new cost of this model if variables 'vars' were removed.


%  This file is a part of the Independent Variable Group Analysis package
% 
%  Copyright (C) 2001-2006 Esa Alhoniemi, Antti Honkela, Krista Lagus,
%  Jeremias Seppa, Harri Valpola, and Paul Wagner
% 
%  This program is free software; you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation; either version 2, or (at your option)
%  any later version.
% 
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License (included in file License.txt in the
%  program package) for more details.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
global State;

types=State.data.types(vars);

if ((sum(types==1)+sum(types==2)) ~= ...
    length(vars)),
  error ('unknown var types!');
end

Params   = this.vq.params;
Var_inds1 = [];
Var_inds2 = [];
Vars_new = this.vars;

typesthis=State.data.types(this.vars);
vars1this=this.vars(typesthis==1);
vars2this=this.vars(typesthis==2);

for i = 1:length(vars)
  if types(i)==1
    Var_inds1 = [Var_inds1 find(vars1this == vars(i))]; 
  else
    Var_inds2 = [Var_inds2 find(vars2this == vars(i))];
  end
  Vars_new(Vars_new == vars(i)) = [];    
end

if isempty(Vars_new) % | isempty(vars)
  new_cost = 0;
  return;
end

if isempty(Params), error( 'The model should be in precomputed state!' ); end

% codebook vectors
Params.Mu_mu(Var_inds1)       = [];
Params.S2_mu(Var_inds1)       = [];

Params.Mu_bar(:,Var_inds1)    = [];
Params.Mu_tilde(:,Var_inds1)  = [];

Params.Alpha_ksi(Var_inds1)   = [];
Params.Beta_ksi(Var_inds1)    = [];

Params.Ksi_alpha(:,Var_inds1) = [];
Params.Ksi_beta(:,Var_inds1)  = [];

Params.U_p(Var_inds2)         = [];

Uhat={};
mask2new=ones(1,length(vars2this));
mask2new(Var_inds2)=0;
j=1;
for i=1:length(vars2this)   %argh
  if mask2new(i)
    Uhat{j}=Params.U_hat{i};
    j=j+1;
  end
end
Params.U_hat=Uhat;

new_cost = vq_cost( State.data, Params, Vars_new, this.s.implicit_noisevar);

return;





