function ivga_compile()

% Compiles the C implementation of the Gaussian mixture model for the IVGA
% Toolbox in the current directory, or for the one found on the Matlab
% path. This command should be given on the same machine where the IVGA Toolbox
% is going to be used.


%  This file is a part of the Independent Variable Group Analysis package
% 
%  Copyright (C) 2001-2006 Esa Alhoniemi, Antti Honkela, Krista Lagus,
%  Jeremias Seppa, Harri Valpola, and Paul Wagner
% 
%  This program is free software; you can redistribute it and/or modify
%  it under the terms of the GNU General Public License as published by
%  the Free Software Foundation; either version 2, or (at your option)
%  any later version.
% 
%  This program is distributed in the hope that it will be useful,
%  but WITHOUT ANY WARRANTY; without even the implied warranty of
%  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%  GNU General Public License (included in file License.txt in the
%  program package) for more details.


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


working_dir = pwd;

mdl_vq_path = which('mdl_vq_real_nominal');
if isempty(mdl_vq_path)
  error([ 'No IVGA Toolbox found in the current directory ' ...
          'or on the Matlab path!' ]);
end

mdl_vq_path( strfind(mdl_vq_path, 'mdl_vq_real_nominal.m'):end ) = [];
cd( mdl_vq_path );
cd( 'private' );

show_path = mdl_vq_path( 1:strfind(mdl_vq_path, '@mdl_vq_real_nominal')-1 );
fprintf( [ 'Compiling the C implementation of the Gaussian mixture model ' ...
           'for the IVGA Toolbox found in directory:\n  %s\n' ], show_path );

answer = input( 'Continue (y/n)? ', 's' );
if answer ~= 'y' && answer ~= 'Y'
  cd( working_dir );
  fprintf('Aborted.\n');
  return;
end

mex -O mix.c
clear functions

cd( working_dir );

return;
